@@ -1,6 +1,4 @@
 import docker
-import hashlib
-import pathlib
 import subprocess
 import json
 import os
@@ -9,8 +7,9 @@ import tarfile
 import progressbar
 import urllib.request
 from simple_file_checksum import get_checksum
-
+import zipfile
 from rayasdk.constants import *
+from rayasdk.messages import *
 from rayasdk.logger import log, LogLevels, log_info, log_error, log_verbose
 from rayasdk.logger import set_logger_level
 from rayasdk import __version__ as RAYA_VERSION
@@ -45,7 +44,7 @@ def launch_command(bash_command, suffix, output_file='', silent=False,
     complete_bash_command += f'{bash_command}'
     if platform.system() == 'Linux':
         sh_command = f'/bin/bash -c "{complete_bash_command}"'
-    else: #Windows
+    else: # Windows and Darwin (Intel for now)
         sh_command = f'/bin/bash -c \'{complete_bash_command}\''
     docker_command = ''
 
@@ -55,7 +54,7 @@ def launch_command(bash_command, suffix, output_file='', silent=False,
         docker_command += '-v /tmp/.X11-unix:/tmp/.X11-unix:ro '
         docker_command += '-e DISPLAY=$DISPLAY --env QT_X11_NO_MITSHM=1 --tty '
         docker_command += f'--name {RAYAENV_DOCKER_CONTAINERPREFIX}_{suffix} '
-    else: #Windows
+    else: # Windows and Darwin (Intel for now)
         docker_command += 'docker run -it --rm --privileged '
         docker_command += '-v /tmp/.X11-unix:/tmp/.X11-unix:ro '
         docker_command += '-e DISPLAY=host.docker.internal:0.0 --tty '
@@ -134,8 +133,10 @@ def run_simulator_bridge():
     if GARYSIM_VERSION not in version:
         if not download_simulator():
             return
-
-    p = subprocess.Popen([str(SIM_BINARY)])
+    if platform.system() == 'Darwin':
+        p = subprocess.Popen([f'open {str(SIM_BINARY)}'], shell=True)
+    else:
+        p = subprocess.Popen([str(SIM_BINARY)])
 
     launch_command(
             ('/opt/raya_os/run_bridge_unity.sh'),
@@ -232,9 +233,10 @@ def check_container():
     try:
         docker_client = docker.from_env()
     except docker.errors.DockerException:
-        log_error(('Docker is not installed or the current user doesn\'t have '
-                   'permissions to run it. Please check the Ra-YA '
-                   'documentation to install it.'))
+        log_error(MSG_DOCKER_NOT_INSTALLER)
+        #maybe required for MAC as well:
+        if platform.system() == 'Windows':
+            log_error(MSG_DOCKER_NOT_RUNNING)
         return False
     
     # Check raya images
@@ -247,7 +249,6 @@ def check_container():
 
     if RAYAENV_DOCKER_VERSION in raya_imgs:
         return True
-
     log_info(('Docker image '
                   f'\'{RAYAENV_DOCKER_IMGNAME}:{RAYAENV_DOCKER_VERSION}\' '
                   'not found.'))
@@ -272,12 +273,15 @@ def check_container():
                 )
 
     log_info(f'Downloading Ra-Ya OS v{RAYAENV_DOCKER_VERSION} (only once)...')
-    try:
-        urllib.request.urlretrieve(RAYAENV_DOCKER_URL, str(RAYAENV_DOCKER_IMGPATH),
-                                MyProgressBar())
-    except urllib.error.HTTPError:
-        log_error('Download error, try again.')
+    try: 
+        os.system(f'gsutil -m cp -r {RAYAENV_DOCKER_URL} {URSDK_TEMP_PATH}')
+    except:
+        log_error('Failed to download Ra-Ya OS image. Please try again.')
         return False
+    log_info('Extracting Ra-Ya OS image.')
+    with zipfile.ZipFile(RAYAENV_DOCKER_ZIPIMGPATH, 'r') as zip_ref:
+        zip_ref.extractall(path=URSDK_TEMP_PATH)
+    
     log_info(f'Checking downloaded file...')
     try:
         sha256 = get_checksum(RAYAENV_DOCKER_IMGPATH, algorithm="SHA256")
